@@ -1,6 +1,7 @@
 import json
 import logging
 import time
+from datetime import datetime
 
 import pandas as pd
 from ccxt.base.exchange import Exchange
@@ -47,9 +48,9 @@ class LoadDataKline:
 
         unix_start = unix_start
         unix_end = unix_end
-        unix_max = unix_max or self.exchange.milliseconds()
-        unix_min = unix_min or self.exchange.milliseconds()
-        print(unix_start, unix_end, unix_max, unix_max)
+        unix_max = unix_max or unix_end
+        unix_min = unix_min or unix_end
+        #print(unix_start, unix_end, unix_max, unix_max)
 
         if unix_min >= unix_start:
             unix_temp = unix_min
@@ -58,7 +59,7 @@ class LoadDataKline:
                 status, result = self._load(symbol, unix_temp - unix_delta, timeframe=timeframe, limit=limit)
                 if status is False:
                     break
-                pbar.set_postfix({'fetch_since': self.exchange.iso8601(result[0][0])})
+                pbar.set_postfix({'time': datetime.fromtimestamp(result[0][0] // 1000)})
                 unix_temp = result[0][0]
 
         if unix_max >= unix_end:
