@@ -1,7 +1,12 @@
-from notecoin.okex.client import (AccountClient, AssetClient, MarketClient,
-                                  PublicClient, TradeClient)
+
 from notetool.secret import read_secret
 
+from .account import AccountClient
+from .asset import AssetClient
+from .market import MarketClient
+from .public import PublicClient
+from .trade import TradeClient
+
 api_key = read_secret(cate1='coin', cate2='okex', cate3='api_key')
 secret_key = read_secret(cate1='coin', cate2='okex', cate3='secret_key')
 passphrase = read_secret(cate1='coin', cate2='okex', cate3='passphrase')
